@@ -144,7 +144,7 @@ shading_hcl <- function(observed, residuals = NULL, expected = NULL, df = NULL,
   if(!is.null(col.bins)) {
     res2 <- col.bins
     res2 <- c(head(res2, 1) - 1, res2[-1] - diff(res2)/2, tail(res2, 1) + 1)
-    legend.col <- hcl(ifelse(res2 > 0, my.h[1], my.h[2]),
+    legend.col <- colorspace::hcl(ifelse(res2 > 0, my.h[1], my.h[2]),
                       max.c * pmax(pmin(interpolate(abs(res2)), 1), 0),
 	              my.l[1] + diff(my.l) * pmax(pmin(interpolate(abs(res2)), 1), 0),
 		      ...)
@@ -158,7 +158,7 @@ shading_hcl <- function(observed, residuals = NULL, expected = NULL, df = NULL,
   rval <- function(x) {
     res <- as.vector(x)
 
-    fill <- hcl(ifelse(res > 0, my.h[1], my.h[2]),
+    fill <- colorspace::hcl(ifelse(res > 0, my.h[1], my.h[2]),
                 max.c * pmax(pmin(interpolate(abs(res)), 1), 0),
 	        my.l[1] + diff(my.l) * pmax(pmin(interpolate(abs(res)), 1), 0),
 	        ...)
@@ -167,8 +167,8 @@ shading_hcl <- function(observed, residuals = NULL, expected = NULL, df = NULL,
     col <- rep(line_col, length.out = length(res))
     if(!is.null(eps)) {
       eps <- abs(eps)
-      col[res > eps] <- hcl(my.h[1], max.c, my.l[2], ...)
-      col[res < -eps] <- hcl(my.h[2], max.c, my.l[2], ...)
+      col[res > eps] <- colorspace::hcl(my.h[1], max.c, my.l[2], ...)
+      col[res < -eps] <- colorspace::hcl(my.h[2], max.c, my.l[2], ...)
     }
     dim(col) <- dim(x)
     
@@ -221,10 +221,11 @@ shading_max <- function(observed = NULL, residuals = NULL, expected = NULL, df =
 class(shading_max) <- "grapcon_generator"
 
 shading_binary <- function(observed = NULL, residuals = NULL, expected = NULL, df = NULL,
-  col = hcl(c(260, 0), 50, 70))
+  col = NULL)
 {
   ## check col argument
-  if (length(col) != 2) stop("Need exactly two colors!")
+  if(is.null(col)) col <- colorspace::hcl(c(260, 0), 50, 70)
+  col <- rep(col, length.out = 2)
   
   ## store color information for legend
   legend <- list(col = col[2:1], col.bins = 0, lty = NULL, lty.bins = NULL)
